#ifndef IDC_STATIC
#define IDC_STATIC (-1)
#endif

#define IDR_MENU                                101
#define IDR_MENU_LAUNCHER                       102
#define IDD_ABOUT                               160
#define IDD_COMPRESSED_FILE                     161
#define IDD_DIPSWITCHES                         162
#define IDD_TAPE_RECORDER                       163
#define IDD_CHEATS                              164
#define IDD_CHEATS_ADDCODE                      165
#define IDD_VIDEO                               166
#define IDD_VIDEO_DECODER                       167
#define IDD_VIDEO_FILTER_STD                    168
#define IDD_VIDEO_FILTER_NTSC                   169
#define IDD_VIDEO_FILTER_SCALEX                 170
#define IDD_VIDEO_FILTER_HQX                    171
#define IDD_INPUT                               172
#define IDD_PATHS                               173
#define IDD_IMAGE_INFO                          174
#define IDD_SOUND                               175
#define IDD_TIMING                              176
#define IDD_PREFERENCES                         177
#define IDD_AUTOSAVER                           178
#define IDD_FDS                                 179
#define IDD_SOUND_RECORDER                      180
#define IDD_MOVIE                               181
#define IDD_LOGFILE                             182
#define IDD_LICENSE                             183
#define IDD_USER_INPUT                          184
#define IDD_LAUNCHER                            185
#define IDD_LAUNCHER_COLUMNS                    187
#define IDD_LAUNCHER_PATHS                      188
#define IDD_LAUNCHER_SEARCH                     189
#define IDD_LAUNCHER_COLORS                     190
#define IDD_NETPLAY                             191
#define IDD_CHAT                                192
#define IDD_INES_HEADER                         193
#define IDD_INES_HEADER_CUSTOM                  194
#define IDD_BARCODE                             195
#define IDD_PALETTE_EDITOR                      196
#define IDD_IMAGE_DATABASE                      197
#define IDD_LANGUAGE                            198
#define IDD_CHOOSE                              199
#define IDD_VIDEO_FILTER_2XSAI                  200
#define IDD_VIDEO_FILTER_XBR                    202
#define IDM_FILE_OPEN                           803
#define IDM_FILE_CLOSE                          804
#define IDM_FILE_LOAD_NST                       805
#define IDM_FILE_SAVE_NST                       806
#define IDM_FILE_QUICK_LOAD_STATE_SLOT_NEWEST   807
#define IDM_FILE_QUICK_LOAD_STATE_SLOT_1        808
#define IDM_FILE_QUICK_LOAD_STATE_SLOT_2        809
#define IDM_FILE_QUICK_LOAD_STATE_SLOT_3        810
#define IDM_FILE_QUICK_LOAD_STATE_SLOT_4        811
#define IDM_FILE_QUICK_LOAD_STATE_SLOT_5        812
#define IDM_FILE_QUICK_LOAD_STATE_SLOT_6        813
#define IDM_FILE_QUICK_LOAD_STATE_SLOT_7        814
#define IDM_FILE_QUICK_LOAD_STATE_SLOT_8        815
#define IDM_FILE_QUICK_LOAD_STATE_SLOT_9        816
#define IDM_FILE_QUICK_SAVE_STATE_SLOT_OLDEST   817
#define IDM_FILE_QUICK_SAVE_STATE_SLOT_1        818
#define IDM_FILE_QUICK_SAVE_STATE_SLOT_2        819
#define IDM_FILE_QUICK_SAVE_STATE_SLOT_3        820
#define IDM_FILE_QUICK_SAVE_STATE_SLOT_4        821
#define IDM_FILE_QUICK_SAVE_STATE_SLOT_5        822
#define IDM_FILE_QUICK_SAVE_STATE_SLOT_6        823
#define IDM_FILE_QUICK_SAVE_STATE_SLOT_7        824
#define IDM_FILE_QUICK_SAVE_STATE_SLOT_8        825
#define IDM_FILE_QUICK_SAVE_STATE_SLOT_9        826
#define IDM_FILE_EDIT_INES_HEADER               827
#define IDM_FILE_SAVE_SCREENSHOT                828
#define IDM_FILE_MOVIE_FILE                     829
#define IDM_FILE_MOVIE_RECORD                   830
#define IDM_FILE_MOVIE_PLAY                     831
#define IDM_FILE_MOVIE_STOP                     832
#define IDM_FILE_MOVIE_REWIND                   833
#define IDM_FILE_MOVIE_FORWARD                  834
#define IDM_FILE_MOVIE_EXPORT_AVI               835
#define IDM_FILE_SOUND_RECORDER_REWIND          836
#define IDM_FILE_SOUND_RECORDER_STOP            837
#define IDM_FILE_SOUND_RECORDER_FILE            838
#define IDM_FILE_SOUND_RECORDER_START           839
#define IDM_FILE_RECENT_1                       840
#define IDM_FILE_RECENT_2                       841
#define IDM_FILE_RECENT_3                       842
#define IDM_FILE_RECENT_4                       843
#define IDM_FILE_RECENT_5                       844
#define IDM_FILE_RECENT_6                       845
#define IDM_FILE_RECENT_7                       846
#define IDM_FILE_RECENT_8                       847
#define IDM_FILE_RECENT_9                       848
#define IDM_FILE_RECENT_LOCK                    849
#define IDM_FILE_RECENT_CLEAR                   850
#define IDM_FILE_RECENT_DIR_1                   851
#define IDM_FILE_RECENT_DIR_2                   852
#define IDM_FILE_RECENT_DIR_3                   853
#define IDM_FILE_RECENT_DIR_4                   854
#define IDM_FILE_RECENT_DIR_5                   855
#define IDM_FILE_RECENT_DIR_LOCK                856
#define IDM_FILE_RECENT_DIR_CLEAR               857
#define IDM_FILE_LAUNCHER                       858
#define IDM_FILE_QUIT                           859
#define IDM_MACHINE_POWER                       860
#define IDM_MACHINE_RESET_SOFT                  861
#define IDM_MACHINE_RESET_HARD                  862
#define IDM_MACHINE_INPUT_AUTOSELECT            863
#define IDM_MACHINE_INPUT_PORT1_UNCONNECTED     864
#define IDM_MACHINE_INPUT_PORT1_PAD1            865
#define IDM_MACHINE_INPUT_PORT1_PAD2            866
#define IDM_MACHINE_INPUT_PORT1_PAD3            867
#define IDM_MACHINE_INPUT_PORT1_PAD4            868
#define IDM_MACHINE_INPUT_PORT1_ZAPPER          869
#define IDM_MACHINE_INPUT_PORT1_PADDLE          870
#define IDM_MACHINE_INPUT_PORT1_POWERPAD        871
#define IDM_MACHINE_INPUT_PORT1_POWERGLOVE      872
#define IDM_MACHINE_INPUT_PORT1_MOUSE           873
#define IDM_MACHINE_INPUT_PORT1_ROB             874
#define IDM_MACHINE_INPUT_PORT2_UNCONNECTED     875
#define IDM_MACHINE_INPUT_PORT2_PAD1            876
#define IDM_MACHINE_INPUT_PORT2_PAD2            877
#define IDM_MACHINE_INPUT_PORT2_PAD3            878
#define IDM_MACHINE_INPUT_PORT2_PAD4            879
#define IDM_MACHINE_INPUT_PORT2_ZAPPER          880
#define IDM_MACHINE_INPUT_PORT2_PADDLE          881
#define IDM_MACHINE_INPUT_PORT2_POWERPAD        882
#define IDM_MACHINE_INPUT_PORT2_POWERGLOVE      883
#define IDM_MACHINE_INPUT_PORT2_MOUSE           884
#define IDM_MACHINE_INPUT_PORT2_ROB             885
#define IDM_MACHINE_INPUT_PORT3_UNCONNECTED     886
#define IDM_MACHINE_INPUT_PORT3_PAD1            887
#define IDM_MACHINE_INPUT_PORT3_PAD2            888
#define IDM_MACHINE_INPUT_PORT3_PAD3            889
#define IDM_MACHINE_INPUT_PORT3_PAD4            890
#define IDM_MACHINE_INPUT_PORT4_UNCONNECTED     891
#define IDM_MACHINE_INPUT_PORT4_PAD1            892
#define IDM_MACHINE_INPUT_PORT4_PAD2            893
#define IDM_MACHINE_INPUT_PORT4_PAD3            894
#define IDM_MACHINE_INPUT_PORT4_PAD4            895
#define IDM_MACHINE_INPUT_EXP_UNCONNECTED       896
#define IDM_MACHINE_INPUT_EXP_FAMILYTRAINER     897
#define IDM_MACHINE_INPUT_EXP_FAMILYBASICKEYBOARD 898
#define IDM_MACHINE_INPUT_EXP_SUBORKEYBOARD     899
#define IDM_MACHINE_INPUT_EXP_DOREMIKKOKEYBOARD 900
#define IDM_MACHINE_INPUT_EXP_HORITRACK         901
#define IDM_MACHINE_INPUT_EXP_PACHINKO          902
#define IDM_MACHINE_INPUT_EXP_PADDLE            903
#define IDM_MACHINE_INPUT_EXP_OEKAKIDSTABLET    904
#define IDM_MACHINE_INPUT_EXP_KONAMIHYPERSHOT   905
#define IDM_MACHINE_INPUT_EXP_BANDAIHYPERSHOT   906
#define IDM_MACHINE_INPUT_EXP_CRAZYCLIMBER      907
#define IDM_MACHINE_INPUT_EXP_MAHJONG           908
#define IDM_MACHINE_INPUT_EXP_EXCITINGBOXING    909
#define IDM_MACHINE_INPUT_EXP_TOPRIDER          910
#define IDM_MACHINE_INPUT_EXP_POKKUNMOGURAA     911
#define IDM_MACHINE_INPUT_EXP_PARTYTAP          912
#define IDM_MACHINE_INPUT_EXP_TURBOFILE         913
#define IDM_MACHINE_INPUT_EXP_BARCODEWORLD      914
#define IDM_MACHINE_INPUT_ADAPTER_AUTO          915
#define IDM_MACHINE_INPUT_ADAPTER_NES           916
#define IDM_MACHINE_INPUT_ADAPTER_FAMICOM       917
#define IDM_MACHINE_EXT_FDS_CHANGE_SIDE         918
#define IDM_MACHINE_EXT_FDS_EJECT_DISK          919
#define IDM_MACHINE_EXT_FDS_OPTIONS             920
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_1_SIDE_A 921
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_1_SIDE_B 922
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_2_SIDE_A 923
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_2_SIDE_B 924
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_3_SIDE_A 925
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_3_SIDE_B 926
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_4_SIDE_A 927
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_4_SIDE_B 928
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_5_SIDE_A 929
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_5_SIDE_B 930
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_6_SIDE_A 931
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_6_SIDE_B 932
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_7_SIDE_A 933
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_7_SIDE_B 934
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_8_SIDE_A 935
#define IDM_MACHINE_EXT_FDS_INSERT_DISK_8_SIDE_B 936
#define IDM_MACHINE_EXT_KEYBOARD_PASTE          937
#define IDM_MACHINE_EXT_TAPE_FILE               938
#define IDM_MACHINE_EXT_TAPE_RECORD             939
#define IDM_MACHINE_EXT_TAPE_PLAY               940
#define IDM_MACHINE_EXT_TAPE_STOP               941
#define IDM_MACHINE_EXT_DIPSWITCHES             942
#define IDM_MACHINE_EXT_BARCODE                 943
#define IDM_MACHINE_SYSTEM_AUTO                 944
#define IDM_MACHINE_SYSTEM_NTSC                 945
#define IDM_MACHINE_SYSTEM_PAL                  946
#define IDM_MACHINE_PAUSE                       947
#define IDM_MACHINE_OPTIONS_UNLIMITEDSPRITES    948
#define IDM_MACHINE_OPTIONS_DIPSWITCHESONLOAD   949
#define IDM_MACHINE_NSF_PLAY                    950
#define IDM_MACHINE_NSF_STOP                    951
#define IDM_MACHINE_NSF_NEXT                    952
#define IDM_MACHINE_NSF_PREV                    953
#define IDM_MACHINE_NSF_OPTIONS_PLAYINBACKGROUND 954
#define IDM_NETPLAY_CONNECTION                  955
#define IDM_NETPLAY_CHAT                        956
#define IDM_VIEW_IMAGE_INFO                     957
#define IDM_VIEW_SWITCH_SCREEN                  958
#define IDM_VIEW_WINDOWSIZE_1X                  959
#define IDM_VIEW_WINDOWSIZE_2X                  960
#define IDM_VIEW_WINDOWSIZE_3X                  961
#define IDM_VIEW_WINDOWSIZE_4X                  962
#define IDM_VIEW_WINDOWSIZE_5X                  963
#define IDM_VIEW_WINDOWSIZE_6X                  964
#define IDM_VIEW_WINDOWSIZE_7X                  965
#define IDM_VIEW_WINDOWSIZE_8X                  966
#define IDM_VIEW_WINDOWSIZE_9X                  967
#define IDM_VIEW_WINDOWSIZE_MAX                 968
#define IDM_VIEW_WINDOWSIZE_TVASPECT            969
#define IDM_VIEW_LOGFILE                        970
#define IDM_VIEW_STATUSBAR                      971
#define IDM_VIEW_MENU                           972
#define IDM_VIEW_ON_TOP                         973
#define IDM_VIEW_FPS                            974
#define IDM_OPTIONS_VIDEO                       975
#define IDM_OPTIONS_SOUND                       976
#define IDM_OPTIONS_INPUT                       977
#define IDM_OPTIONS_TIMING                      978
#define IDM_OPTIONS_PATHS                       979
#define IDM_OPTIONS_CHEATS                      980
#define IDM_OPTIONS_PREFERENCES                 981
#define IDM_OPTIONS_IMAGEDATABASE               982
#define IDM_OPTIONS_LANGUAGE                    983
#define IDM_OPTIONS_AUTOSAVER                   984
#define IDM_OPTIONS_AUTOSAVER_START             985
#define IDM_HELP_HELP                           986
#define IDM_HELP_ABOUT                          987
#define IDM_HELP_LICENSE                        988
#define IDC_PREFERENCES_PRIORITY                1001
#define IDC_PREFERENCES_DISABLE_STATUSMSG       1002
#define IDM_LAUNCHER_FILE_RUN                   1002
#define IDM_LAUNCHER_FILE_EDITHEADER            1003
#define IDM_LAUNCHER_FILE_REFRESH               1004
#define IDM_LAUNCHER_EDIT_FIND                  1005
#define IDM_LAUNCHER_EDIT_REMOVE                1006
#define IDM_LAUNCHER_EDIT_INSERT                1007
#define IDM_LAUNCHER_EDIT_CLEAR                 1008
#define IDM_LAUNCHER_VIEW_SHOWGRIDS             1009
#define IDM_LAUNCHER_VIEW_SHOWDATABASECORRECTED 1010
#define IDM_LAUNCHER_VIEW_ONTOP                 1011
#define IDM_LAUNCHER_VIEW_ALIGNCOLUMNS          1012
#define IDM_LAUNCHER_OPTIONS_PATHS              1013
#define IDM_LAUNCHER_OPTIONS_COLUMNS            1014
#define IDM_LAUNCHER_OPTIONS_COLORS             1015
#define IDC_SOUND_DEVICE                        2001
#define IDC_SOUND_SAMPLE_RATE                   2002
#define IDC_SOUND_LATENCY                       2005
#define IDC_SOUND_LATENCY_ONE                   2006
#define IDC_SOUND_LATENCY_TEN                   2007
#define IDC_SOUND_MONO                          2008
#define IDC_SOUND_STEREO                        2009
#define IDC_SOUND_POOL_SYSTEM                   2010
#define IDC_SOUND_POOL_HARDWARE                 2011
#define IDC_SOUND_ADJUST_PITCH                  2012
#define IDC_SOUND_MASTER_SLIDER                 2013
#define IDC_SOUND_MASTER_VALUE                  2014
#define IDC_SOUND_MASTER_TEXT                   2015
#define IDC_SOUND_SQUARE1_SLIDER                2016
#define IDC_SOUND_SQUARE1_VALUE                 2017
#define IDC_SOUND_SQUARE1_TEXT                  2018
#define IDC_SOUND_SQUARE2_SLIDER                2019
#define IDC_SOUND_SQUARE2_VALUE                 2020
#define IDC_SOUND_SQUARE2_TEXT                  2021
#define IDC_SOUND_TRIANGLE_SLIDER               2022
#define IDC_SOUND_TRIANGLE_VALUE                2023
#define IDC_SOUND_TRIANGLE_TEXT                 2024
#define IDC_SOUND_NOISE_SLIDER                  2025
#define IDC_SOUND_NOISE_VALUE                   2026
#define IDC_SOUND_NOISE_TEXT                    2027
#define IDC_SOUND_DPCM_SLIDER                   2028
#define IDC_SOUND_DPCM_VALUE                    2029
#define IDC_SOUND_DPCM_TEXT                     2030
#define IDC_SOUND_FDS_SLIDER                    2031
#define IDC_SOUND_FDS_VALUE                     2032
#define IDC_SOUND_FDS_TEXT                      2033
#define IDC_SOUND_MMC5_SLIDER                   2034
#define IDC_SOUND_MMC5_VALUE                    2035
#define IDC_SOUND_MMC5_TEXT                     2036
#define IDC_SOUND_VRC6_SLIDER                   2037
#define IDC_SOUND_VRC6_VALUE                    2038
#define IDC_SOUND_VRC6_TEXT                     2039
#define IDC_SOUND_VRC7_SLIDER                   2040
#define IDC_SOUND_VRC7_VALUE                    2041
#define IDC_SOUND_VRC7_TEXT                     2042
#define IDC_SOUND_N163_SLIDER                   2043
#define IDC_SOUND_N163_VALUE                    2044
#define IDC_SOUND_N163_TEXT                     2045
#define IDC_SOUND_S5B_SLIDER                    2046
#define IDC_SOUND_S5B_VALUE                     2047
#define IDC_SOUND_S5B_TEXT                      2048
#define IDC_SOUND_RESET_SLIDERS                 2049
#define IDC_SOUND_DEFAULT                       2050
#define IDC_INPUT_DEVICES                       2100
#define IDC_INPUT_MAP                           2101
#define IDC_INPUT_KEYS                          2102
#define IDC_INPUT_KEYPRESS_TEXT                 2103
#define IDC_INPUT_CLEAR                         2104
#define IDC_INPUT_SET                           2105
#define IDC_INPUT_DEFAULT                       2106
#define IDC_INPUT_SETALL                        2108
#define IDC_INPUT_DEFAULT_CATEGORY              2109
#define IDC_INPUT_CLEARALL                      2110
#define IDC_INPUT_AUTOFIRE_SLIDER               2111
#define IDC_INPUT_AUTOFIRE_DEFAULT              2112
#define IDC_INPUT_JOYSTICKS                     2115
#define IDC_INPUT_JOYSTICKS_ENABLE              2116
#define IDC_INPUT_JOYSTICKS_X                   2117
#define IDC_INPUT_JOYSTICKS_Y                   2118
#define IDC_INPUT_JOYSTICKS_Z                   2119
#define IDC_INPUT_JOYSTICKS_RX                  2120
#define IDC_INPUT_JOYSTICKS_RY                  2121
#define IDC_INPUT_JOYSTICKS_RZ                  2122
#define IDC_INPUT_JOYSTICKS_S0                  2123
#define IDC_INPUT_JOYSTICKS_S1                  2124
#define IDC_INPUT_JOYSTICKS_POV0                2125
#define IDC_INPUT_JOYSTICKS_POV1                2126
#define IDC_INPUT_JOYSTICKS_POV2                2127
#define IDC_INPUT_JOYSTICKS_POV3                2128
#define IDC_INPUT_JOYSTICKS_DEADZONE            2129
#define IDC_INPUT_JOYSTICKS_DEADZONE_NUM        2130
#define IDC_INPUT_JOYSTICKS_DEADZONE_TEXT       2131
#define IDC_INPUT_JOYSTICKS_CALIBRATE           2132
#define IDC_INPUT_JOYSTICKS_DEFAULT             2133
#define IDC_INPUT_ALLOW_SIMUL_AXES              2134
#define IDC_PATHS_IMAGE                         2200
#define IDC_PATHS_BATTERY                       2201
#define IDC_PATHS_NST                           2202
#define IDC_PATHS_CHEATS                        2203
#define IDC_PATHS_PATCHES                       2204
#define IDC_PATHS_SCREENSHOTS                   2205
#define IDC_PATHS_SAMPLES                       2206
#define IDC_PATHS_IMAGE_LAST                    2207
#define IDC_PATHS_IMAGE_BROWSE                  2208
#define IDC_PATHS_BATTERY_BROWSE                2209
#define IDC_PATHS_NST_BROWSE                    2210
#define IDC_PATHS_CHEATS_BROWSE                 2211
#define IDC_PATHS_PATCHES_BROWSE                2212
#define IDC_PATHS_SCREENSHOTS_BROWSE            2213
#define IDC_PATHS_SAMPLES_BROWSE                2214
#define IDC_PATHS_NST_COMPRESS                  2215
#define IDC_PATHS_NST_AUTO_IMPORT               2216
#define IDC_PATHS_NST_AUTO_EXPORT               2217
#define IDC_PATHS_BATTERY_PROTECT               2218
#define IDC_PATHS_PATCHES_AUTO_APPLY            2219
#define IDC_PATHS_PATCHES_BYPASS_VALIDATION     2220
#define IDC_PATHS_DEFAULT                       2221
#define IDC_PATHS_SCREENSHOTS_PNG               2222
#define IDC_PATHS_SCREENSHOTS_JPEG              2223
#define IDC_PATHS_SCREENSHOTS_BMP               2224
#define IDC_PATHS_CHEATS_AUTO_LOAD              2225
#define IDC_PATHS_CHEATS_AUTO_SAVE              2226
#define IDC_COMPRESSED_FILE_LIST                2300
#define IDC_IMAGE_INFO_EDIT                     2400
#define IDC_DIPSWITCHES_1_TEXT                  2500
#define IDC_DIPSWITCHES_2_TEXT                  2501
#define IDC_DIPSWITCHES_3_TEXT                  2502
#define IDC_DIPSWITCHES_4_TEXT                  2503
#define IDC_DIPSWITCHES_5_TEXT                  2504
#define IDC_DIPSWITCHES_6_TEXT                  2505
#define IDC_DIPSWITCHES_7_TEXT                  2506
#define IDC_DIPSWITCHES_8_TEXT                  2507
#define IDC_DIPSWITCHES_1                       2508
#define IDC_DIPSWITCHES_2                       2509
#define IDC_DIPSWITCHES_3                       2510
#define IDC_DIPSWITCHES_4                       2511
#define IDC_DIPSWITCHES_5                       2512
#define IDC_DIPSWITCHES_6                       2513
#define IDC_DIPSWITCHES_7                       2514
#define IDC_DIPSWITCHES_8                       2515
#define IDC_DIPSWITCHES_GROUP                   2516
#define IDC_VIDEO_DEVICE                        2600
#define IDC_VIDEO_MODE                          2601
#define IDC_VIDEO_EFFECTS                       2602
#define IDC_VIDEO_FILTER_SETTINGS               2603
#define IDC_VIDEO_16_BIT                        2604
#define IDC_VIDEO_32_BIT                        2605
#define IDC_VIDEO_NESTEXTURE_VIDMEM             2606
#define IDC_VIDEO_NESTEXTURE_SYSMEM             2607
#define IDC_VIDEO_NTSC_LEFT                     2608
#define IDC_VIDEO_NTSC_TOP                      2609
#define IDC_VIDEO_NTSC_RIGHT                    2610
#define IDC_VIDEO_NTSC_BOTTOM                   2611
#define IDC_VIDEO_PAL_LEFT                      2612
#define IDC_VIDEO_PAL_TOP                       2613
#define IDC_VIDEO_PAL_RIGHT                     2614
#define IDC_VIDEO_PAL_BOTTOM                    2615
#define IDC_VIDEO_COLORS_BRIGHTNESS             2616
#define IDC_VIDEO_COLORS_SATURATION             2617
#define IDC_VIDEO_COLORS_CONTRAST               2618
#define IDC_VIDEO_COLORS_HUE                    2619
#define IDC_VIDEO_COLORS_BRIGHTNESS_VAL         2620
#define IDC_VIDEO_COLORS_SATURATION_VAL         2621
#define IDC_VIDEO_COLORS_CONTRAST_VAL           2622
#define IDC_VIDEO_COLORS_HUE_VAL                2623
#define IDC_VIDEO_COLORS_RESET                  2624
#define IDC_VIDEO_COLORS_ADVANCED               2625
#define IDC_VIDEO_PALETTE_AUTO                  2626
#define IDC_VIDEO_PALETTE_YUV                   2627
#define IDC_VIDEO_PALETTE_RGB                   2628
#define IDC_VIDEO_PALETTE_CUSTOM                2629
#define IDC_VIDEO_PALETTE_PATH                  2630
#define IDC_VIDEO_PALETTE_BROWSE                2631
#define IDC_VIDEO_PALETTE_CLEAR                 2632
#define IDC_VIDEO_PALETTE_EDITOR                2633
#define IDC_VIDEO_AUTO_HZ                       2634
#define IDC_VIDEO_SC_SLIDER                     2635
#define IDC_VIDEO_SC_VALUE                      2636
#define IDC_VIDEO_DEFAULT                       2637
#define IDC_VIDEO_FILTER_DEFAULT                2650
#define IDC_VIDEO_FILTER_BILINEAR               2651
#define IDC_VIDEO_FILTER_SCANLINES_SLIDER       2652
#define IDC_VIDEO_FILTER_SCANLINES_VAL          2653
#define IDC_VIDEO_FILTER_NTSC_AUTO_TUNING       2656
#define IDC_VIDEO_FILTER_NTSC_FIELDS_AUTO       2657
#define IDC_VIDEO_FILTER_NTSC_FIELDS_ON         2658
#define IDC_VIDEO_FILTER_NTSC_FIELDS_OFF        2659
#define IDC_VIDEO_FILTER_NTSC_SHARPNESS_SLIDER  2660
#define IDC_VIDEO_FILTER_NTSC_RESOLUTION_SLIDER 2661
#define IDC_VIDEO_FILTER_NTSC_COLORBLEED_SLIDER 2662
#define IDC_VIDEO_FILTER_NTSC_ARTIFACTS_SLIDER  2663
#define IDC_VIDEO_FILTER_NTSC_FRINGING_SLIDER   2664
#define IDC_VIDEO_FILTER_NTSC_SHARPNESS_VAL     2665
#define IDC_VIDEO_FILTER_NTSC_RESOLUTION_VAL    2666
#define IDC_VIDEO_FILTER_NTSC_COLORBLEED_VAL    2667
#define IDC_VIDEO_FILTER_NTSC_ARTIFACTS_VAL     2668
#define IDC_VIDEO_FILTER_NTSC_FRINGING_VAL      2669
#define IDC_VIDEO_FILTER_NTSC_SHARPNESS_TEXT    2670
#define IDC_VIDEO_FILTER_NTSC_RESOLUTION_TEXT   2671
#define IDC_VIDEO_FILTER_NTSC_COLORBLEED_TEXT   2672
#define IDC_VIDEO_FILTER_NTSC_ARTIFACTS_TEXT    2673
#define IDC_VIDEO_FILTER_NTSC_FRINGING_TEXT     2674
#define IDC_VIDEO_FILTER_NTSC_COMPOSITE         2675
#define IDC_VIDEO_FILTER_NTSC_SVIDEO            2676
#define IDC_VIDEO_FILTER_NTSC_RGB               2677
#define IDC_VIDEO_FILTER_SCALEX_2X              2683
#define IDC_VIDEO_FILTER_SCALEX_3X              2684
#define IDC_VIDEO_FILTER_SCALEX_AUTO            2685
#define IDC_VIDEO_FILTER_HQX_SCALING_2X         2686
#define IDC_VIDEO_FILTER_HQX_SCALING_3X         2687
#define IDC_VIDEO_FILTER_HQX_SCALING_4X         2688
#define IDC_VIDEO_FILTER_HQX_SCALING_AUTO       2689
#define IDC_CHEATS_STATIC_CODES                 2700
#define IDC_CHEATS_TEMP_CODES                   2701
#define IDC_CHEATS_STATIC_ADD                   2702
#define IDC_CHEATS_TEMP_ADD                     2703
#define IDC_CHEATS_STATIC_EDIT                  2704
#define IDC_CHEATS_TEMP_EDIT                    2705
#define IDC_CHEATS_STATIC_REMOVE                2706
#define IDC_CHEATS_TEMP_REMOVE                  2707
#define IDC_CHEATS_STATIC_IMPORT                2708
#define IDC_CHEATS_TEMP_IMPORT                  2709
#define IDC_CHEATS_STATIC_EXPORT                2710
#define IDC_CHEATS_TEMP_EXPORT                  2711
#define IDC_CHEATS_STATIC_CLEAR                 2712
#define IDC_CHEATS_TEMP_CLEAR                   2713
#define IDC_CHEATS_ADDCODE_USE_RAW              2714
#define IDC_CHEATS_ADDCODE_USE_GENIE            2715
#define IDC_CHEATS_ADDCODE_USE_ROCKY            2716
#define IDC_CHEATS_ADDCODE_ADDRESS              2717
#define IDC_CHEATS_ADDCODE_VALUE                2718
#define IDC_CHEATS_ADDCODE_COMPARE              2719
#define IDC_CHEATS_ADDCODE_ROCKY                2720
#define IDC_CHEATS_ADDCODE_GENIE                2721
#define IDC_CHEATS_ADDCODE_SUBMIT               2722
#define IDC_CHEATS_ADDCODE_GAME                 2723
#define IDC_CHEATS_ADDCODE_RESULT               2724
#define IDC_CHEATS_ADDCODE_VALIDATE             2725
#define IDC_CHEATS_ADDCODE_DESC                 2726
#define IDC_CHEATS_ADDCODE_USE_HEX              2727
#define IDC_CHEATS_ADDCODE_SEARCH_TEXT_A        2728
#define IDC_CHEATS_ADDCODE_SEARCH_TEXT_B        2729
#define IDC_CHEATS_ADDCODE_SEARCH_A             2730
#define IDC_CHEATS_ADDCODE_SEARCH_B             2731
#define IDC_CHEATS_ADDCODE_SEARCH_LIST          2732
#define IDC_CHEATS_ADDCODE_SEARCH_NONE          2733
#define IDC_CHEATS_ADDCODE_SEARCH_R0_A_R1_B     2734
#define IDC_CHEATS_ADDCODE_SEARCH_R0_A_R0R1_B   2735
#define IDC_CHEATS_ADDCODE_SEARCH_R0R1_B        2736
#define IDC_CHEATS_ADDCODE_SEARCH_R0_L_R1       2737
#define IDC_CHEATS_ADDCODE_SEARCH_R0_G_R1       2738
#define IDC_CHEATS_ADDCODE_SEARCH_R0_N_R1       2739
#define IDC_CHEATS_ADDCODE_SEARCH_RESET         2740
#define IDC_CHEATS_ADDCODE_GAME_CURRENT         2741
#define IDC_CHEATS_ADDCODE_GAME_BROWSE          2742
#define IDC_CHEATS_SHOW_HEX                     2743
#define IDC_PREFERENCES_DEFAULT                 2800
#define IDC_PREFERENCES_STARTUP_FULLSCREEN      2801
#define IDC_PREFERENCES_DISABLE_ROM_WARNINGS    2802
#define IDC_PREFERENCES_CLOSE_POWER_OFF         2803
#define IDC_PREFERENCES_CONFIRM_EXIT            2804
#define IDC_PREFERENCES_RUN_IN_BACKGROUND       2805
#define IDC_PREFERENCES_BEGIN_EMULATION         2806
#define IDC_PREFERENCES_SAVE_LOGFILE            2807
#define IDC_PREFERENCES_MULTIPLE_INSTANCES      2808
#define IDC_PREFERENCES_SAVE_LAUNCHER           2809
#define IDC_PREFERENCES_CONFIRM_RESET           2810
#define IDC_PREFERENCES_SAVE_CHEATCODES         2811
#define IDC_PREFERENCES_SAVE_NETPLAY_GAMELIST   2812
#define IDC_PREFERENCES_SAVE_WINDOWPOS          2813
#define IDC_PREFERENCES_SAVE_LAUNCHERSIZE       2814
#define IDC_PREFERENCES_ICON_NES                2815
#define IDC_PREFERENCES_ICON_UNF                2816
#define IDC_PREFERENCES_ICON_FDS                2817
#define IDC_PREFERENCES_ICON_NSF                2818
#define IDC_PREFERENCES_ASSOCIATE_NES           2819
#define IDC_PREFERENCES_ASSOCIATE_UNF           2820
#define IDC_PREFERENCES_ASSOCIATE_FDS           2821
#define IDC_PREFERENCES_ASSOCIATE_NSF           2822
#define IDC_PREFERENCES_STYLE_NES               2823
#define IDC_PREFERENCES_STYLE_FAMICOM           2824
#define IDC_PREFERENCES_MENUCOLOR_FULLSCREEN_DEFAULT 2826
#define IDC_PREFERENCES_MENUCOLOR_DESKTOP_DEFAULT 2827
#define IDC_PREFERENCES_MENUCOLOR_FULLSCREEN_CHANGE 2828
#define IDC_PREFERENCES_MENUCOLOR_DESKTOP_CHANGE 2829
#define IDC_PREFERENCES_FAVORED_NES_NTSC        2830
#define IDC_PREFERENCES_FAVORED_NES_PAL         2831
#define IDC_PREFERENCES_FAVORED_FAMICOM         2832
#define IDC_PREFERENCES_FAVORED_ALWAYS_ASK      2833
#define IDC_PREFERENCES_FAVORED_DENDY           2834
#define IDC_FDS_BROWSE                          2900
#define IDC_FDS_CLEAR                           2901
#define IDC_FDS_BIOS                            2902
#define IDC_FDS_SAVEDISABLE                     2906
#define IDC_FDS_SAVETOIMAGE                     2907
#define IDC_FDS_SAVETOPATCH                     2908
#define IDC_FDS_LED_DISABLE                     2909
#define IDC_FDS_LED_SCREEN                      2910
#define IDC_FDS_LED_NUMLOCK                     2911
#define IDC_FDS_LED_CAPSLOCK                    2912
#define IDC_FDS_LED_SCROLLLOCK                  2913
#define IDC_FDS_DEFAULT                         2914
#define IDC_AUTOSAVE_FILE                       3000
#define IDC_AUTOSAVE_BROWSE                     3001
#define IDC_AUTOSAVE_TIME                       3002
#define IDC_AUTOSAVE_CLEAR                      3003
#define IDC_AUTOSAVE_ENABLE_MSG                 3005
#define IDC_SOUND_CAPTURE_FILE                  3100
#define IDC_SOUND_CAPTURE_CLEAR                 3101
#define IDC_SOUND_CAPTURE_BROWSE                3102
#define IDC_MOVIE_FILE                          3200
#define IDC_MOVIE_CLEAR                         3201
#define IDC_MOVIE_BROWSE                        3202
#define IDC_LOGFILE_CLEAR                       3300
#define IDC_LOGFILE_EDIT                        3302
#define IDC_LICENSE_EDIT                        3304
#define IDC_ABOUT_ICON                          3400
#define IDC_ABOUT_URL                           3401
#define IDC_ABOUT_NAMEVERSION                   3404
#define IDC_USER_INPUT_EDIT                     3502
#define IDC_USER_INPUT_TEXT                     3503
#define IDC_TIMING_SYNC_REFRESH                 3600
#define IDC_TIMING_AUTO_FRAME_SKIP              3601
#define IDC_TIMING_VSYNC                        3602
#define IDC_TIMING_PFC                          3603
#define IDC_TIMING_SPEED                        3604
#define IDC_TIMING_SPEED_NUM                    3605
#define IDC_TIMING_DEFAULT_SPEED                3606
#define IDC_TIMING_FRAME_SKIPS                  3607
#define IDC_TIMING_FRAME_SKIPS_NUM              3608
#define IDC_TIMING_FRAME_SKIPS_TEXT             3609
#define IDC_TIMING_ALT_SPEED                    3610
#define IDC_TIMING_ALT_SPEED_NUM                3611
#define IDC_TIMING_REWINDER                     3612
#define IDC_TIMING_REWINDER_NOSOUND             3613
#define IDC_TIMING_REWINDER_DEFAULT_SPEED       3614
#define IDC_TIMING_REWINDER_SPEED               3615
#define IDC_TIMING_REWINDER_SPEED_NUM           3616
#define IDC_TIMING_TRIPLE_BUFFERING             3617
#define IDC_TIMING_ALT_SPEED_NOSOUND            3618
#define IDC_TIMING_DEFAULT                      3619
#define IDC_LAUNCHER_LIST                       3900
#define IDC_LAUNCHER_COLUMNSELECT_SELECTED      3903
#define IDC_LAUNCHER_COLUMNSELECT_AVAILABLE     3904
#define IDC_LAUNCHER_TREE                       3905
#define IDC_LAUNCHER_PATHS_LIST                 3906
#define IDC_LAUNCHER_PATHS_NES                  3907
#define IDC_LAUNCHER_PATHS_UNF                  3908
#define IDC_LAUNCHER_PATHS_FDS                  3909
#define IDC_LAUNCHER_PATHS_NSF                  3910
#define IDC_LAUNCHER_PATHS_PATCH                3911
#define IDC_LAUNCHER_PATHS_ARCHIVE              3912
#define IDC_LAUNCHER_PATHS_CLEAR                3913
#define IDC_LAUNCHER_PATHS_ALLFILES             3914
#define IDC_LAUNCHER_PATHS_UNIQUEFILES          3915
#define IDC_LAUNCHER_PATHS_ADD                  3916
#define IDC_LAUNCHER_PATHS_REMOVE               3917
#define IDC_LAUNCHER_PATHS_XML                  3918
#define IDC_LAUNCHER_FILESEARCH_FILE            3922
#define IDC_LAUNCHER_COLORS_DEFAULT             3924
#define IDC_LAUNCHER_COLORS_FG_CHANGE           3925
#define IDC_LAUNCHER_COLORS_BG_CHANGE           3926
#define IDC_LAUNCHER_COLUMNSELECT_DEFAULT       3927
#define IDC_LAUNCHER_COLUMNSELECT_REMOVE        3928
#define IDC_LAUNCHER_COLUMNSELECT_ADD           3929
#define IDC_NETPLAY_LAUNCH                      3930
#define IDC_NETPLAY_GAMELIST                    3931
#define IDC_NETPLAY_ADD                         3932
#define IDC_NETPLAY_REMOVE                      3933
#define IDC_NETPLAY_CLEAR                       3934
#define IDC_NETPLAY_DEFAULT                     3935
#define IDC_NETPLAY_PLAY_FULLSCREEN             3936
#define IDC_CHAT_EDIT                           4000
#define IDC_INES_HEADER_TYPE_STD                4100
#define IDC_INES_HEADER_TYPE_EXT                4101
#define IDC_INES_HEADER_PRGROM_LIST             4102
#define IDC_INES_HEADER_PRGROM_TEXT             4103
#define IDC_INES_HEADER_PRGRAM_LIST             4104
#define IDC_INES_HEADER_PRGRAM_TEXT             4105
#define IDC_INES_HEADER_PRGNVRAM_LIST           4106
#define IDC_INES_HEADER_PRGNVRAM_TEXT           4107
#define IDC_INES_HEADER_CHRROM_LIST             4108
#define IDC_INES_HEADER_CHRROM_TEXT             4109
#define IDC_INES_HEADER_CHRRAM_LIST             4110
#define IDC_INES_HEADER_CHRRAM_TEXT             4111
#define IDC_INES_HEADER_CHRNVRAM_LIST           4112
#define IDC_INES_HEADER_CHRNVRAM_TEXT           4113
#define IDC_INES_HEADER_HORIZONTAL              4114
#define IDC_INES_HEADER_VERTICAL                4115
#define IDC_INES_HEADER_FOURSCREEN              4116
#define IDC_INES_HEADER_SYSTEM_HOME             4117
#define IDC_INES_HEADER_SYSTEM_VS               4118
#define IDC_INES_HEADER_SYSTEM_PC10             4119
#define IDC_INES_HEADER_REGION_NTSC             4120
#define IDC_INES_HEADER_REGION_PAL              4121
#define IDC_INES_HEADER_REGION_BOTH             4122
#define IDC_INES_HEADER_MAPPER_BASE_VALUE       4123
#define IDC_INES_HEADER_MAPPER_BASE_TEXT        4124
#define IDC_INES_HEADER_MAPPER_SUB_VALUE        4125
#define IDC_INES_HEADER_MAPPER_SUB_TEXT         4126
#define IDC_INES_HEADER_TRAINER                 4127
#define IDC_INES_HEADER_VS_PPU_LIST             4128
#define IDC_INES_HEADER_VS_PPU_TEXT             4129
#define IDC_INES_HEADER_VS_MODE_LIST            4130
#define IDC_INES_HEADER_VS_MODE_TEXT            4131
#define IDC_INES_HEADER_UNDOALL                 4132
#define IDC_INES_HEADER_SAVE                    4133
#define IDC_INES_HEADER_CUSTOM_VALUE            4140
#define IDC_LANGUAGE_LIST                       4200
#define IDC_BARCODE_DIGITS                      4300
#define IDC_BARCODE_TRANSFER                    4301
#define IDC_BARCODE_RANDOM                      4302
#define IDC_TAPE_RECORDER_FILE                  4473
#define IDC_TAPE_RECORDER_BROWSE                4474
#define IDC_TAPE_RECORDER_CLEAR                 4475
#define IDC_TAPE_RECORDER_USE_IMAGENAME         4478
#define IDC_PALETTE_EDITOR_UNDO                 4500
#define IDC_PALETTE_EDITOR_REDO                 4501
#define IDC_PALETTE_EDITOR_RESET                4502
#define IDC_PALETTE_EDITOR_SAVE                 4503
#define IDC_PALETTE_EDITOR_R_SLIDER             4505
#define IDC_PALETTE_EDITOR_G_SLIDER             4506
#define IDC_PALETTE_EDITOR_B_SLIDER             4507
#define IDC_PALETTE_EDITOR_R_VALUE              4508
#define IDC_PALETTE_EDITOR_G_VALUE              4509
#define IDC_PALETTE_EDITOR_B_VALUE              4510
#define IDC_PALETTE_EDITOR_CUSTOM               4511
#define IDC_PALETTE_EDITOR_YUV                  4512
#define IDC_PALETTE_EDITOR_RGB                  4513
#define IDC_PALETTE_EDITOR_HEX                  4514
#define IDC_PALETTE_EDITOR_INDEX                4515
#define IDC_VIDEO_DECODER_RY_VALUE              4600
#define IDC_VIDEO_DECODER_GY_VALUE              4601
#define IDC_VIDEO_DECODER_BY_VALUE              4602
#define IDC_VIDEO_DECODER_RY_NUM                4603
#define IDC_VIDEO_DECODER_GY_NUM                4604
#define IDC_VIDEO_DECODER_BY_NUM                4605
#define IDC_VIDEO_DECODER_RY_GAIN               4606
#define IDC_VIDEO_DECODER_GY_GAIN               4607
#define IDC_VIDEO_DECODER_BY_GAIN               4608
#define IDC_VIDEO_DECODER_BOOST_YELLOW          4609
#define IDC_VIDEO_DECODER_CANONICAL             4610
#define IDC_VIDEO_DECODER_CONSUMER              4611
#define IDC_VIDEO_DECODER_ALTERNATIVE           4612
#define IDC_IMAGEDATABASE_DEFAULT               4620
#define IDC_IMAGEDATABASE_FILE                  4621
#define IDC_IMAGEDATABASE_BROWSE                4622
#define IDC_IMAGEDATABASE_CLEAR                 4623
#define IDC_IMAGEDATABASE_INTERNAL              4624
#define IDC_IMAGEDATABASE_EXTERNAL              4625
#define IDC_CHOOSE_LIST                         4630
#define IDC_DIPSWITCHES_DONTSHOWAGAIN           5244
#define IDC_VIDEO_DECODER_CXA2025AS_US          40000
#define IDS_TITLE_NESTOPIA                      40000
#define IDS_TITLE_ERROR                         40001
#define IDC_VIDEO_DECODER_CXA2025AS_JP          40002
#define IDS_TITLE_WARNING                       40002
#define IDS_TITLE_EXIT                          40003
#define IDS_ARE_YOU_SURE                        40004
#define IDS_ERR_SYNTAX                          40005
#define IDS_ERR_GENERIC                         40006
#define IDS_ERR_OUT_OF_MEMORY                   40007
#define IDS_ERR_BAD_BPP                         40008
#define IDS_ERR_D3D_FAILED                      40009
#define IDS_ERR_D3D_DEVICE_FAILED               40010
#define IDS_ERR_INVALID_SIZE                    40011
#define IDS_ERR_FAILED                          40012
#define IDS_ERR_SOUND_FAILED                    40013
#define IDS_TEXT_NONE                           40014
#define IDS_TEXT_DISK                           40015
#define IDS_TEXT_START                          40016
#define IDS_TEXT_STOP                           40017
#define IDS_TEXT_FIND                           40018
#define IDS_TEXT_SEARCH_NOT_FOUND               40019
#define IDS_TEXT_ENABLED                        40020
#define IDS_TEXT_DISABLED                       40021
#define IDS_TEXT_OTHER                          40022
#define IDS_TEXT_OK                             40023
#define IDS_TEXT_SYSTEM                         40024
#define IDS_TEXT_YES                            40025
#define IDS_TEXT_NO                             40026
#define IDS_TEXT_UNKNOWN                        40027
#define IDS_TEXT_REPAIRABLE                     40028
#define IDS_TEXT_BAD                            40029
#define IDS_TEXT_FILE                           40030
#define IDS_TEXT_DIRECTORY                      40031
#define IDS_TEXT_NAME                           40032
#define IDS_TEXT_COPYRIGHT                      40033
#define IDS_TEXT_REGION                         40034
#define IDS_TEXT_FPS                            40035
#define IDS_TEXT_BOARD                          40036
#define IDS_TEXT_MAPPER                         40037
#define IDS_TEXT_HORIZONTAL                     40038
#define IDS_INPUT_NSF_KEY_PREV                  40039
#define IDS_INPUT_VIEW_KEY_SCREENSIZE_1X        40040
#define IDS_INPUT_VIEW_KEY_SCREENSIZE_2X        40041
#define IDS_INPUT_VIEW_KEY_SCREENSIZE_3X        40042
#define IDS_INPUT_VIEW_KEY_SCREENSIZE_4X        40043
#define IDS_INPUT_VIEW_KEY_SCREENSIZE_5X        40044
#define IDS_INPUT_VIEW_KEY_SCREENSIZE_6X        40045
#define IDS_INPUT_VIEW_KEY_SCREENSIZE_7X        40046
#define IDS_INPUT_VIEW_KEY_SCREENSIZE_8X        40047
#define IDS_INPUT_VIEW_KEY_SCREENSIZE_9X        40048
#define IDS_INPUT_VIEW_KEY_SCREENSIZE_MAX       40049
#define IDS_INPUT_VIEW_KEY_SHOW_MENU            40050
#define IDS_INPUT_VIEW_KEY_SHOW_STATUSBAR       40051
#define IDS_INPUT_VIEW_KEY_SHOW_ONTOP           40052
#define IDS_INPUT_VIEW_KEY_SHOW_FPS             40053
#define IDS_INPUT_VIEW_KEY_FULLSCREEN           40054
#define IDS_INPUT_HELP_KEY_HELP                 40055
#define IDS_MENU_NETPLAY_CONNECT                40056
#define IDS_MENU_NETPLAY_DISCONNECT             40057
#define IDS_TEXT_DEFAULT                        40058
#define IDS_TEXT_ALTNAME                        40059
#define IDS_FILE_ERR_READONLY                   40060
#define IDS_VIDEO_FILTER_2XSAI                  40061
#define IDS_VIDEO_FILTER_XBR                    40062
#define IDS_TEXT_SOFTPATCHED                    40063
#define IDS_EMU_WARN_PATCH_LOAD_ERR             40064
#define IDS_INCOMPATIBLE_RESOURCE               40065
#define IDS_CHEAT_COMPARE                       40066
#define IDS_CHEAT_GAME                          40067
#define IDS_CHEAT_DESCRIPTION                   40068
#define IDS_DIALOG_INPUT_PRESS_ANY_KEY_MENU     40069
#define IDS_DIALOG_INPUT_PRESS_ANY_KEY_INVALID  40070
#define IDS_DIALOG_INPUT_PRESS_ANY_KEY_EMU      40071
#define IDS_DIALOG_INPUT_DUPLICATE_KEYS         40072
#define IDS_DIALOG_VIDEO_INVALID_PALETTE        40073
#define IDS_DIALOG_VIDEO_ADAPTER_INDEX_SUFFIX   40074
#define IDS_DIALOG_PREFERENCES_REGISTRYUPDATED  40075
#define IDS_DIALOG_PREFERENCES_REGISTRYUPDATED_TITLE 40076
#define IDS_MACHINE_POWER_OFF_TITLE             40077
#define IDS_MACHINE_RESET_TITLE                 40078
#define IDS_CARTRIDGE_LOAD_FAILED               40079
#define IDS_CARTRIDGE_SAVE_FAILED               40080
#define IDS_EMU_WARN_BAD_PROM                   40081
#define IDS_EMU_WARN_BAD_CROM                   40082
#define IDS_TEXT_DENDY                          40083
#define IDS_EMU_WARN_ENCRYPTED                  40084
#define IDS_EMU_CRC_MISSMATCH_CONTINUE          40085
#define IDS_EMU_CRC_MISSMATCH                   40086
#define IDS_EMU_FDS_NO_FILE                     40087
#define IDS_EMU_FDS_SUPPLY_BIOS                 40088
#define IDS_EMU_SAMPLES_UNAVAILABLE             40089
#define IDS_TEXT_ABORT                          40090
#define IDS_EMU_MOVIE_SAVE_IMAGEDATA            40091
#define IDS_EMU_MOVIE_SAVE_FDS                  40092
#define IDS_EMU_MOVIE_SAVE_TURBOFILE            40093
#define IDS_EMU_MOVIE_SAVE_TAPE                 40094
#define IDS_EMU_MOVIE_SAVE_EEPROM               40095
#define IDS_ERR_INVALID_CHECKSUM                40096
#define IDS_TEXT_TRAINER                        40097
#define IDS_TEXT_DUMP                           40098
#define IDS_TEXT_FILES                          40099
#define IDS_TEXT_SAYS                           40100
#define IDS_TEXT_DROPPEDOUT                     40101
#define IDS_TEXT_PLAYER                         40102
#define IDS_TEXT_IN_FILES                       40103
#define IDS_TEXT_SOLDERPAD                      40104
#define IDS_TEXT_CHIPS                          40105
#define IDS_TEXT_PLAYERS                        40106
#define IDS_TEXT_DEVELOPER                      40107
#define IDS_TEXT_PUBLISHER                      40108
#define IDS_TEXT_VSDUALSYSTEM                   40109
#define IDS_TEXT_VSUNISYSTEM                    40110
#define IDS_TEXT_FAMICOM                        40111
#define IDS_TEXT_NES_PAL                        40112
#define IDS_TEXT_NES_NTSC                       40113
#define IDS_TEXT_PLAYCHOICE10                   40114
#define IDS_TEXT_ANY                            40115
#define IDS_FILE_ERR_READ                       40116
#define IDS_FILE_ERR_WRITE                      40117
#define IDS_FILE_ERR_OPEN                       40118
#define IDS_FILE_ERR_NOTFOUND                   40119
#define IDS_FILE_ERR_ALREADYEXISTS              40120
#define IDS_FILE_ERR_TOOBIG                     40121
#define IDS_FILE_ERR_INVALID                    40122
#define IDS_FILE_ERR_EMPTY                      40123
#define IDS_FILE_ERR_CORRUPT                    40124
#define IDS_FILE_ERR_NOTHING_IN_ARCHIVE         40125
#define IDS_FILE_ERR_CANT_USE_IN_ARCHIVE        40126
#define IDS_FILE_ERR_CREATE_DIR                 40127
#define IDS_FILE_ASK_CREATE_DIR                 40128
#define IDS_TEXT_VERTICAL                       40129
#define IDS_TEXT_FOURSCREEN                     40130
#define IDS_TEXT_SINGLESCREEN                   40131
#define IDS_TEXT_MAPPERCONTROLLED               40132
#define IDS_TEXT_BATTERY                        40133
#define IDS_TEXT_MIRRORING                      40134
#define IDS_TEXT_TRAILING_DATA                  40135
#define IDS_TEXT_HEADER                         40136
#define IDS_TEXT_ARTIST                         40137
#define IDS_TEXT_SONGS                          40138
#define IDS_TEXT_STARTINGSONG                   40139
#define IDS_TEXT_EXTRACHIPS                     40140
#define IDS_TEXT_BANKSWITCHING                  40141
#define IDS_TEXT_LOADADDRESS                    40142
#define IDS_TEXT_INITADDRESS                    40143
#define IDS_TEXT_PLAYADDRESS                    40144
#define IDS_AUTOSAVER_START                     40145
#define IDS_AUTOSAVER_STOP                      40146
#define IDS_SCREEN_LOADED                       40147
#define IDS_SCREEN_UNLOADED                     40148
#define IDS_SCREEN_POWER_ON                     40149
#define IDS_SCREEN_POWER_OFF                    40150
#define IDS_SCREEN_RESET_HARD                   40151
#define IDS_SCREEN_RESET_SOFT                   40152
#define IDS_SCREEN_NTSC                         40153
#define IDS_SCREEN_PAL                          40154
#define IDS_SCREEN_PAUSE                        40155
#define IDS_SCREEN_RESUME                       40156
#define IDS_SCREEN_SCREENSHOT_SAVED_TO          40157
#define IDS_SCREEN_DISK_SIDE_A_INSERTED         40158
#define IDS_SCREEN_DISK_SIDE_B_INSERTED         40159
#define IDS_SCREEN_DISK_EJECTED                 40160
#define IDS_SCREEN_SAVE_STATE_TO                40161
#define IDS_SCREEN_LOAD_STATE_FROM              40162
#define IDS_SCREEN_SAVE_STATE_TO_SLOT           40163
#define IDS_SCREEN_LOAD_STATE_FROM_SLOT         40164
#define IDS_SCREEN_CPU_JAM                      40165
#define IDS_SCREEN_FDS_READING                  40166
#define IDS_SCREEN_FDS_WRITING                  40167
#define IDS_SCREEN_SOUND_RECORDER_RESUME        40168
#define IDS_SCREEN_SOUND_RECORDER_START         40169
#define IDS_SCREEN_SOUND_RECORDER_STOP          40170
#define IDS_SCREEN_SOUND_RECORDER_WRITTEN       40171
#define IDS_SCREEN_MOVIE_PLAY_STARTED           40172
#define IDS_SCREEN_MOVIE_PLAY_STOPPED           40173
#define IDS_SCREEN_MOVIE_REC_STARTED            40174
#define IDS_SCREEN_MOVIE_REC_STOPPED            40175
#define IDS_SCREEN_MOVIE_REWOUND                40176
#define IDS_FILE_ERR_WRITE_PROTECTED            40177
#define IDS_EMU_ERR_GENERIC                     40178
#define IDS_EMU_ERR_UNSUPPORTED_MAPPER          40179
#define IDS_EMU_ERR_UNSUPPORTED_VSSYSTEM        40180
#define IDS_EMU_ERR_BIOS_FILE_MISSING           40181
#define IDS_EMU_ERR_SAVE_STATE                  40182
#define IDS_EMU_ERR_LOAD_STATE                  40183
#define IDS_EMU_ERR_UNSUPPORTED_FILE_VERSION    40184
#define IDS_EMU_ERR_MOVIE_REC                   40185
#define IDS_EMU_ERR_MOVIE_PLAY                  40186
#define IDS_EMU_ERR_CANT_REWIND                 40187
#define IDS_EMU_ERR_LOAD_SAMPLES                40188
#define IDS_EMU_ERR_WRONG_MODE                  40189
#define IDS_EMU_WARN_PATCHING_FAILED            40190
#define IDS_EMU_WARN_BAD_INES                   40191
#define IDS_EMU_WARN_BAD_DUMP                   40192
#define IDS_MENU_FULLSCREEN                     40193
#define IDS_MENU_DESKTOP                        40194
#define IDS_MENU_POWER_ON                       40195
#define IDS_MENU_POWER_OFF                      40196
#define IDS_MENU_X                              40197
#define IDS_FDS_PATCHDATALOAD_FAILED            40198
#define IDS_FDS_PATCHDATASAVE_FAILED            40199
#define IDS_FDS_SAVE_FAILED                     40200
#define IDS_FDS_DISK_SIDE_A                     40201
#define IDS_FDS_DISK_SIDE_B                     40202
#define IDS_FDS_ERR_INVALIDBIOS                 40203
#define IDS_FDS_NONSTANDARD                     40204
#define IDS_SCREENSHOT_SAVE_FAILED              40205
#define IDS_SCREENSHOT_UNSUPPORTED_FORMAT       40206
#define IDS_WAVE_ERR_OPEN                       40207
#define IDS_WAVE_ERR_WRITE                      40208
#define IDS_WAVE_ERR_READ                       40209
#define IDS_WAVE_ERR_FINALIZE                   40210
#define IDS_WAVE_WARN_FILE_BIG                  40211
#define IDS_VIDEO_FILTER_STD                    40212
#define IDS_VIDEO_FILTER_NTSC                   40213
#define IDS_VIDEO_FILTER_SCALEX                 40214
#define IDS_VIDEO_FILTER_HQX                    40215
#define IDS_VIDEO_PALETTE_SAVE_EMPH             40216
#define IDS_INES_HEADER_INVALID                 40217
#define IDS_INES_HEADER_UNSAFE                  40218
#define IDS_INES_HEADER_REMOVE_RESERVED         40219
#define IDS_AVI_WRITE_ERR                       40220
#define IDS_AVI_WRITE_INFO                      40221
#define IDS_AVI_WRITE_ABORT                     40222
#define IDS_AVI_WRITE_FINISHED                  40223
#define IDS_LANGUAGE_UPDATE                     40224
#define IDS_INPUT_JOY_GUID_MISMATCH             40225
#define IDS_INPUT_KEY_SECTION_PAD1              40226
#define IDS_INPUT_KEY_SECTION_PAD2              40227
#define IDS_INPUT_KEY_SECTION_PAD3              40228
#define IDS_INPUT_KEY_SECTION_PAD4              40229
#define IDS_INPUT_KEY_SECTION_POWERPAD          40230
#define IDS_INPUT_KEY_SECTION_POWERGLOVE        40231
#define IDS_INPUT_KEY_SECTION_HORITRACK         40232
#define IDS_INPUT_KEY_SECTION_PACHINKO          40233
#define IDS_INPUT_KEY_SECTION_CRAZYCLIMBER      40234
#define IDS_INPUT_KEY_SECTION_MAHJONG           40235
#define IDS_INPUT_KEY_SECTION_EXCITINGBOXING    40236
#define IDS_INPUT_KEY_SECTION_POKKUNMOGURAA     40237
#define IDS_INPUT_KEY_SECTION_PARTYTAP          40238
#define IDS_INPUT_KEY_SECTION_KARAOKESTUDIO     40239
#define IDS_SCREEN_MOVIE_FORWARDED              40240
#define IDS_SCREEN_NOSPRITELIMIT_ON             40241
#define IDS_SCREEN_NOSPRITELIMIT_OFF            40242
#define IDS_SCREEN_TEXT_PASTE                   40243
#define IDS_SCREEN_TAPE_RECORDING               40244
#define IDS_SCREEN_TAPE_PLAYING                 40245
#define IDS_SCREEN_TAPE_STOPPED                 40246
#define IDS_SCREEN_HORITRACK_SPEED_LOW          40247
#define IDS_SCREEN_HORITRACK_SPEED_HIGH         40248
#define IDS_SCREEN_HORITRACK_ORIENTATION_LEFT   40249
#define IDS_SCREEN_HORITRACK_ORIENTATION_RIGHT  40250
#define IDS_FILES_SUPPORTED                     40251
#define IDS_FILES_XML                           40252
#define IDS_FILES_INES                          40253
#define IDS_FILES_UNIF                          40254
#define IDS_FILES_FDS                           40255
#define IDS_FILES_NSF                           40256
#define IDS_FILES_ROM                           40257
#define IDS_EXT_DATABASE_LOAD_FAILED            40258
#define IDS_FILES_BATTERY                       40259
#define IDS_FILES_TAPE                          40260
#define IDS_FILES_STATE                         40261
#define IDS_FILES_STATE_SLOTS                   40262
#define IDS_FILES_MOVIE                         40263
#define IDS_FILES_PATCHES                       40264
#define IDS_FILES_PALETTE                       40265
#define IDS_FILES_WAVE                          40266
#define IDS_FILES_AVI                           40267
#define IDS_FILES_ARCHIVE                       40268
#define IDS_FILES_ALL                           40269
#define IDS_LAUNCHER_ERR_LOAD_DB                40270
#define IDS_LAUNCHER_ERR_SAVE_DB                40271
#define IDS_LAUNCHER_COLUMN_FILE                40272
#define IDS_LAUNCHER_COLUMN_SYSTEM              40273
#define IDS_LAUNCHER_COLUMN_MAPPER              40274
#define IDS_LAUNCHER_COLUMN_PRG                 40275
#define IDS_LAUNCHER_COLUMN_CHR                 40276
#define IDS_LAUNCHER_COLUMN_WRAM                40277
#define IDS_LAUNCHER_COLUMN_VRAM                40278
#define IDS_LAUNCHER_COLUMN_BATTERY             40279
#define IDS_LAUNCHER_COLUMN_DUMP                40280
#define IDS_LAUNCHER_COLUMN_NAME                40281
#define IDS_LAUNCHER_COLUMN_FOLDER              40282
#define IDS_TEXT_NES_PAL_A                      40283
#define IDS_LAUNCHER_SECTION_ALL                40284
#define IDS_LAUNCHER_SECTION_XML                40285
#define IDS_LAUNCHER_SECTION_NES                40286
#define IDS_LAUNCHER_SECTION_UNIF               40287
#define IDS_LAUNCHER_SECTION_FDS                40288
#define IDS_LAUNCHER_SECTION_NSF                40289
#define IDS_LAUNCHER_SECTION_PATCH              40290
#define IDS_TEXT_NES_PAL_B                      40291
#define IDS_LAUNCHER_SECTION_ARCHIVE            40292
#define IDS_LOAD_APPLY_CURRENT_GAME             40293
#define IDS_LOAD_SPECIFY_FILE                   40294
#define IDS_CHEATS                              40295
#define IDS_CHEATS_EXPORTEXISTING               40296
#define IDS_CHEATS_EXPORTEXISTING_ERROR         40297
#define IDS_CHEATS_INVALID_CODE                 40298
#define IDS_CHEATS_RESULT_VALID                 40299
#define IDS_CHEATS_RESULT_INVALID               40300
#define IDS_CHEAT_CODE                          40301
#define IDS_CHEAT_ADDRESS                       40302
#define IDS_CHEAT_VALUE                         40303
#define IDS_INPUT_KEY_SECTION_EMULATION         40304
#define IDS_INPUT_KEY_SECTION_FILE              40305
#define IDS_INPUT_KEY_SECTION_MACHINE           40306
#define IDS_INPUT_KEY_SECTION_NSF               40307
#define IDS_INPUT_KEY_SECTION_VIEW              40308
#define IDS_INPUT_KEY_SECTION_HELP              40309
#define IDS_INPUT_PAD_KEY_LEFT                  40310
#define IDS_INPUT_PAD_KEY_UP                    40311
#define IDS_INPUT_PAD_KEY_RIGHT                 40312
#define IDS_INPUT_PAD_KEY_DOWN                  40313
#define IDS_INPUT_PAD_KEY_SELECT                40314
#define IDS_INPUT_PAD_KEY_START                 40315
#define IDS_INPUT_PAD_KEY_B                     40316
#define IDS_INPUT_PAD_KEY_A                     40317
#define IDS_INPUT_PAD_KEY_AUTOFIRE_B            40318
#define IDS_INPUT_PAD_KEY_AUTOFIRE_A            40319
#define IDS_INPUT_PARTYTAP_UNIT_3               40320
#define IDS_INPUT_PARTYTAP_UNIT_4               40321
#define IDS_INPUT_PARTYTAP_UNIT_5               40322
#define IDS_INPUT_PARTYTAP_UNIT_6               40323
#define IDS_INPUT_KARAOKESTUDIO_MIC             40324
#define IDS_INPUT_KARAOKESTUDIO_A               40325
#define IDS_INPUT_KARAOKESTUDIO_B               40326
#define IDS_INPUT_EMULATION_KEY_ALT_SPEED       40327
#define IDS_INPUT_EMULATION_KEY_REWIND          40328
#define IDS_INPUT_EMULATION_KEY_INSERT_COIN_1   40329
#define IDS_INPUT_EMULATION_KEY_INSERT_COIN_2   40330
#define IDS_INPUT_FILE_KEY_OPEN                 40331
#define IDS_INPUT_FILE_KEY_SAVE_STATE           40332
#define IDS_CHOOSE_GAME                         40333
#define IDS_INPUT_FILE_KEY_LOAD_STATE           40334
#define IDS_CHOOSE_FILE                         40335
#define IDS_INPUT_FILE_KEY_QUICK_LOAD_STATE_1   40336
#define IDS_INPUT_FILE_KEY_QUICK_LOAD_STATE_2   40337
#define IDS_INPUT_FILE_KEY_QUICK_LOAD_STATE_3   40338
#define IDS_INPUT_FILE_KEY_QUICK_LOAD_STATE_4   40339
#define IDS_INPUT_FILE_KEY_QUICK_LOAD_STATE_5   40340
#define IDS_INPUT_FILE_KEY_QUICK_LOAD_STATE_6   40341
#define IDS_INPUT_FILE_KEY_QUICK_LOAD_STATE_7   40342
#define IDS_INPUT_FILE_KEY_QUICK_LOAD_STATE_8   40343
#define IDS_INPUT_FILE_KEY_QUICK_LOAD_STATE_9   40344
#define IDS_INPUT_FILE_KEY_QUICK_LOAD_LAST_STATE 40345
#define IDS_INPUT_FILE_KEY_QUICK_SAVE_STATE_1   40346
#define IDS_INPUT_FILE_KEY_QUICK_SAVE_STATE_2   40347
#define IDS_INPUT_FILE_KEY_QUICK_SAVE_STATE_3   40348
#define IDS_INPUT_FILE_KEY_QUICK_SAVE_STATE_4   40349
#define IDS_INPUT_FILE_KEY_QUICK_SAVE_STATE_5   40350
#define IDS_INPUT_FILE_KEY_QUICK_SAVE_STATE_6   40351
#define IDS_INPUT_FILE_KEY_QUICK_SAVE_STATE_7   40352
#define IDS_INPUT_FILE_KEY_QUICK_SAVE_STATE_8   40353
#define IDS_INPUT_FILE_KEY_QUICK_SAVE_STATE_9   40354
#define IDS_INPUT_FILE_KEY_QUICK_SAVE_NEXT_STATE 40355
#define IDS_INPUT_FILE_KEY_SAVE_SCREENSHOT      40356
#define IDS_INPUT_FILE_KEY_LAUNCHER             40357
#define IDS_INPUT_FILE_KEY_EXIT                 40358
#define IDS_INPUT_MACHINE_KEY_POWER             40359
#define IDS_INPUT_MACHINE_KEY_RESET_SOFT        40360
#define IDS_INPUT_MACHINE_KEY_RESET_HARD        40361
#define IDS_INPUT_MACHINE_KEY_PAUSE             40362
#define IDS_INPUT_MACHINE_KEY_UNLIMITED_SPRITES 40363
#define IDS_INPUT_MACHINE_KEY_CHANGE_DISK_SIDE  40364
#define IDS_INPUT_NSF_KEY_PLAY                  40365
#define IDS_INPUT_NSF_KEY_STOP                  40366
#define IDS_INPUT_NSF_KEY_NEXT                  40367
#define IDS_INPUT_PAD_KEY_MIC                   40368
#define IDS_INPUT_POWERPAD_KEY_SIDE_A_1         40369
#define IDS_INPUT_POWERPAD_KEY_SIDE_A_2         40370
#define IDS_INPUT_POWERPAD_KEY_SIDE_A_3         40371
#define IDS_INPUT_POWERPAD_KEY_SIDE_A_4         40372
#define IDS_INPUT_POWERPAD_KEY_SIDE_A_5         40373
#define IDS_INPUT_POWERPAD_KEY_SIDE_A_6         40374
#define IDS_INPUT_POWERPAD_KEY_SIDE_A_7         40375
#define IDS_INPUT_POWERPAD_KEY_SIDE_A_8         40376
#define IDS_INPUT_POWERPAD_KEY_SIDE_A_9         40377
#define IDS_INPUT_POWERPAD_KEY_SIDE_A_10        40378
#define IDS_INPUT_POWERPAD_KEY_SIDE_A_11        40379
#define IDS_INPUT_POWERPAD_KEY_SIDE_A_12        40380
#define IDS_INPUT_POWERPAD_KEY_SIDE_B_3         40381
#define IDS_INPUT_POWERPAD_KEY_SIDE_B_2         40382
#define IDS_INPUT_POWERPAD_KEY_SIDE_B_8         40383
#define IDS_INPUT_POWERPAD_KEY_SIDE_B_7         40384
#define IDS_INPUT_POWERPAD_KEY_SIDE_B_6         40385
#define IDS_INPUT_POWERPAD_KEY_SIDE_B_5         40386
#define IDS_INPUT_POWERPAD_KEY_SIDE_B_11        40387
#define IDS_INPUT_POWERPAD_KEY_SIDE_B_10        40388
#define IDS_INPUT_POWERGLOVE_KEY_SELECT         40389
#define IDS_INPUT_POWERGLOVE_KEY_START          40390
#define IDS_INPUT_POWERGLOVE_KEY_MOVE_IN        40391
#define IDS_INPUT_POWERGLOVE_KEY_MOVE_OUT       40392
#define IDS_INPUT_POWERGLOVE_KEY_ROLL_LEFT      40393
#define IDS_INPUT_POWERGLOVE_KEY_ROLL_RIGHT     40394
#define IDS_INPUT_HORITRACK_KEY_LEFT            40395
#define IDS_INPUT_HORITRACK_KEY_UP              40396
#define IDS_INPUT_HORITRACK_KEY_RIGHT           40397
#define IDS_INPUT_HORITRACK_KEY_DOWN            40398
#define IDS_INPUT_HORITRACK_KEY_SELECT          40399
#define IDS_INPUT_HORITRACK_KEY_START           40400
#define IDS_INPUT_HORITRACK_KEY_B               40401
#define IDS_INPUT_HORITRACK_KEY_A               40402
#define IDS_INPUT_HORITRACK_KEY_SPEED           40403
#define IDS_INPUT_HORITRACK_KEY_ORIENTATION     40404
#define IDS_INPUT_PACHINKO_KEY_LEFT             40405
#define IDS_INPUT_PACHINKO_KEY_UP               40406
#define IDS_INPUT_PACHINKO_KEY_RIGHT            40407
#define IDS_INPUT_PACHINKO_KEY_DOWN             40408
#define IDS_INPUT_PACHINKO_KEY_SELECT           40409
#define IDS_INPUT_PACHINKO_KEY_START            40410
#define IDS_INPUT_PACHINKO_KEY_B                40411
#define IDS_INPUT_PACHINKO_KEY_A                40412
#define IDS_INPUT_CRAZYCLIMBER_KEY_LEFT_UP      40413
#define IDS_INPUT_CRAZYCLIMBER_KEY_LEFT_RIGHT   40414
#define IDS_INPUT_CRAZYCLIMBER_KEY_LEFT_DOWN    40415
#define IDS_INPUT_CRAZYCLIMBER_KEY_LEFT_LEFT    40416
#define IDS_INPUT_CRAZYCLIMBER_KEY_RIGHT_UP     40417
#define IDS_INPUT_CRAZYCLIMBER_KEY_RIGHT_RIGHT  40418
#define IDS_INPUT_CRAZYCLIMBER_KEY_RIGHT_DOWN   40419
#define IDS_INPUT_CRAZYCLIMBER_KEY_RIGHT_LEFT   40420
#define IDS_INPUT_MAHJONG_KEY_A                 40421
#define IDS_INPUT_MAHJONG_KEY_B                 40422
#define IDS_INPUT_MAHJONG_KEY_C                 40423
#define IDS_INPUT_MAHJONG_KEY_D                 40424
#define IDS_INPUT_MAHJONG_KEY_E                 40425
#define IDS_INPUT_MAHJONG_KEY_F                 40426
#define IDS_INPUT_MAHJONG_KEY_G                 40427
#define IDS_INPUT_MAHJONG_KEY_H                 40428
#define IDS_INPUT_MAHJONG_KEY_I                 40429
#define IDS_INPUT_MAHJONG_KEY_J                 40430
#define IDS_INPUT_MAHJONG_KEY_K                 40431
#define IDS_INPUT_MAHJONG_KEY_L                 40432
#define IDS_INPUT_MAHJONG_KEY_M                 40433
#define IDS_INPUT_MAHJONG_KEY_N                 40434
#define IDS_INPUT_MAHJONG_KEY_START             40435
#define IDS_INPUT_MAHJONG_KEY_SELECT            40436
#define IDS_INPUT_MAHJONG_KEY_KAN               40437
#define IDS_INPUT_MAHJONG_KEY_PON               40438
#define IDS_INPUT_MAHJONG_KEY_CHI               40439
#define IDS_INPUT_MAHJONG_KEY_REACH             40440
#define IDS_INPUT_MAHJONG_KEY_RON               40441
#define IDS_INPUT_EXCITINGBOXING_KEY_LEFT_HOOK  40442
#define IDS_INPUT_EXCITINGBOXING_KEY_RIGHT_HOOK 40443
#define IDS_INPUT_EXCITINGBOXING_KEY_LEFT_JAB   40444
#define IDS_INPUT_EXCITINGBOXING_KEY_RIGHT_JAB  40445
#define IDS_INPUT_EXCITINGBOXING_KEY_STRAIGHT   40446
#define IDS_INPUT_EXCITINGBOXING_KEY_BODY       40447
#define IDS_INPUT_EXCITINGBOXING_KEY_LEFT_MOVE  40448
#define IDS_INPUT_EXCITINGBOXING_KEY_RIGHT_MOVE 40449
#define IDS_INPUT_POKKUNMOGURAA_KEY_ROW_1_1     40450
#define IDS_INPUT_POKKUNMOGURAA_KEY_ROW_1_2     40451
#define IDS_INPUT_POKKUNMOGURAA_KEY_ROW_1_3     40452
#define IDS_INPUT_POKKUNMOGURAA_KEY_ROW_1_4     40453
#define IDS_INPUT_POKKUNMOGURAA_KEY_ROW_2_1     40454
#define IDS_INPUT_POKKUNMOGURAA_KEY_ROW_2_2     40455
#define IDS_INPUT_POKKUNMOGURAA_KEY_ROW_2_3     40456
#define IDS_INPUT_POKKUNMOGURAA_KEY_ROW_2_4     40457
#define IDS_INPUT_POKKUNMOGURAA_KEY_ROW_3_1     40458
#define IDS_INPUT_POKKUNMOGURAA_KEY_ROW_3_2     40459
#define IDS_INPUT_POKKUNMOGURAA_KEY_ROW_3_3     40460
#define IDS_INPUT_POKKUNMOGURAA_KEY_ROW_3_4     40461
#define IDS_INPUT_PARTYTAP_UNIT_1               40462
#define IDS_INPUT_PARTYTAP_UNIT_2               40463
#define IDS_PRIORITY_NORMAL                     40464
#define IDS_PRIORITY_ABOVE_NORMAL               40465
#define IDS_PRIORITY_HIGH                       40466
#define IDC_VIDEO_FILTER_BLEND                  40467
#define IDC_VIDEO_FILTER_XBR_SCALING_AUTO       40469
#define IDC_VIDEO_FILTER_XBR_SCALING_2X         40471
#define IDC_VIDEO_FILTER_XBR_SCALING_3X         40474
#define IDC_VIDEO_FILTER_XBR_SCALING_4X         40475
#define IDC_VIDEO_FILTER_XBR_ROUNDING_ALL       40477
#define IDC_VIDEO_FILTER_XBR_ROUNDING_SOME      40479
#define IDC_VIDEO_FILTER_XBR_ROUNDING_NONE      40481
#define IDC_VIDEO_FILTER_XBR_CREDIT             40482
